/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.adaptrex.core.ext;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

//import org.apache.log4j.Logger;

import com.fasterxml.jackson.annotation.JsonInclude;

public class StoreDefinition {

//	private static Logger log = Logger.getLogger(StoreDefinition.class);

	private Boolean clearOnPageLoad;
	private Boolean clearRemovedOnLoad;
	private Boolean autoSync;
	private Boolean autoLoad;
	private Boolean remoteGroup;
	private Boolean remoteSort;
	private Boolean remoteFilter;
	private Boolean sortOnFilter;
	
	private Boolean buffered;
	private Integer trailingBufferZone;
	private Integer leadingBufferZone;
	private Integer purgePageCount;

	private List<Sorter> groupers = new ArrayList<Sorter>();
	private List<Sorter> sorters = new ArrayList<Sorter>();
	
	private Integer pageSize;

	private List<Filter> filters = new ArrayList<Filter>();
	
	private String modelName;
	private RestProxy restProxy;
	
	private List<Map<String, Object>> data = new ArrayList<Map<String, Object>>();
	
	@JsonInclude
	public final String extend = "Ext.data.Store";

	
	public StoreDefinition() {}

	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	public List<Map<String, Object>> getData() {
		return this.data;
	}
	
	public void setData(List<Map<String, Object>> data) {
		this.data = data;
	}

	/*
	 * We always return the name of the model
	 */
	@JsonInclude
	public String getModel() {
		return this.modelName;
	}

	/*
	 * Below are just a list of getters and setters including information to
	 * help jackson serialize them properly
	 */
	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Integer getPageSize() {
		return this.pageSize;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isClearOnPageLoad() {
		return this.clearOnPageLoad;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isClearRemovedOnLoad() {
		return this.clearRemovedOnLoad;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isAutoSync() {
		return this.autoSync;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isBuffered() {
		return this.buffered;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Object getAutoLoad() {
		return this.autoLoad;
	}

	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	public List<Sorter> getGroupers() {
		return this.groupers;
	}

	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	public List<Sorter> getSorters() {
		return this.sorters;
	}

	@JsonInclude(JsonInclude.Include.NON_EMPTY)
	public List<Filter> getFilters() {
		return this.filters;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Integer getLeadingBufferZone() {
		return this.leadingBufferZone;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Integer getTrailingBufferZone() {
		return this.trailingBufferZone;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isRemoteGroup() {
		return this.remoteGroup;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isRemoteSort() {
		return this.remoteSort;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isRemoteFilter() {
		return this.remoteFilter;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Boolean isSortOnFilter() {
		return this.sortOnFilter;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public Integer getPurgePageCount() {
		return this.purgePageCount;
	}

	@JsonInclude(JsonInclude.Include.NON_NULL)
	public RestProxy getRestProxy() {
		return restProxy;
	}


	public void setClearOnPageLoad(Boolean clearOnPageLoad) {
		this.clearOnPageLoad = clearOnPageLoad;
	}



	public void setClearRemovedOnLoad(Boolean clearRemovedOnLoad) {
		this.clearRemovedOnLoad = clearRemovedOnLoad;
	}



	public void setAutoSync(Boolean autoSync) {
		this.autoSync = autoSync;
	}



	public void setAutoLoad(Boolean autoLoad) {
		this.autoLoad = autoLoad;
	}



	public void setRemoteGroup(Boolean remoteGroup) {
		this.remoteGroup = remoteGroup;
	}



	public void setRemoteSort(Boolean remoteSort) {
		this.remoteSort = remoteSort;
	}



	public void setRemoteFilter(Boolean remoteFilter) {
		this.remoteFilter = remoteFilter;
	}



	public void setSortOnFilter(Boolean sortOnFilter) {
		this.sortOnFilter = sortOnFilter;
	}



	public void setBuffered(Boolean buffered) {
		this.buffered = buffered;
	}



	public void setTrailingBufferZone(Integer trailingBufferZone) {
		this.trailingBufferZone = trailingBufferZone;
	}



	public void setLeadingBufferZone(Integer leadingBufferZone) {
		this.leadingBufferZone = leadingBufferZone;
	}



	public void setPurgePageCount(Integer purgePageCount) {
		this.purgePageCount = purgePageCount;
	}



	public void setGroupers(List<Sorter> groupers) {
		this.groupers = groupers;
	}



	public void setSorters(List<Sorter> sorters) {
		this.sorters = sorters;
	}



	public void setPageSize(Integer pageSize) {
		this.pageSize = pageSize;
	}



	public void setFilters(List<Filter> filters) {
		this.filters = filters;
	}



	public void setModelName(String modelName) {
		this.modelName = modelName;
	}


	public void setRestProxy(RestProxy restProxy) {
		this.restProxy = restProxy;
	}
}
