/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.adaptrex.core.persistence.api;

import java.util.Map;

import com.adaptrex.core.ext.ExtConfig;

public interface ORMPersistenceManager {

	public Object				getFactory();
	public Object				getSession();
	public ORMModelDefinition	getModelDefinition(ExtConfig extConfig);
	public void					shutdown();
	public Class<?>				getEntityClass(String className);
	public boolean				isManyToOne(Class<?> clazz, String fieldName);
	public boolean				isOneToMany(Class<?> clazz, String fieldName);
	public boolean				isIdField(Class<?> clazz, String fieldName);
	public String				getFieldType(Class<?> clazz, String fieldName);
	public boolean				isManyToMany(Class<?> clazz, String fieldName);
	public boolean				isAssociated(Class<?> clazz, String associationName);
	public Class<?>				getFieldEntityClass(Class<?> clazz, String fieldName);
	public ORMModelInstance		getModelInstance(ExtConfig extConfig, Object entity);
	public Object				getEntity(Class<?> clazz, Object id);
	public Object				getEntity(Class<?> clazz, String key, Object value);
	public Object				getFieldValue(Object entity, String fieldName);
	public Object				getEntityId(Object entity);
	public ORMStoreData			getStoreData(ExtConfig extConfig);
	
	public ORMModelInstance		createModelinstance(ExtConfig extConfig, Map<String,Object> data);
	public ORMModelInstance		updateModelInstance(ExtConfig extConfig, Object id, Map<String,Object> data);
	public ORMModelInstance		deleteModelInstance(ExtConfig extConfig, Object id);
}
  