/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.adaptrex.core.rest;

import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.UriInfo;

import com.adaptrex.core.AdaptrexRegistry;

public class AdaptrexRestApi {

	@Context protected UriInfo uriInfo;
	private String modelName;
	
    @GET
    public RestStore getStore() {
    	return getRest().getStore(this.modelName, uriInfo);
    }

    @GET @Path("{id}")
    public RestModel getModel(@PathParam("id") Integer id) {
    	return getRest().getModel(this.modelName, id, uriInfo);
    }
    
    @POST
    public RestModel createModel(RequestBody modelUpdate) {
    	return getRest().createModel(this.modelName, modelUpdate, uriInfo);
    }
    
    @PUT @Path("{id}")
    public RestModel updateModel(@PathParam("id") Integer id, RequestBody modelUpdate) {
    	return getRest().updateModel(this.modelName, id, modelUpdate, uriInfo);
    }

    @DELETE @Path("{id}")
    public RestModel deleteModel(@PathParam("id") Integer id) {
    	return getRest().deleteModel(this.modelName, id);
    }
    
    public void setModelName(String modelName) {
    	this.modelName = modelName;
    }
    
    private RestService getRest() {
    	return AdaptrexRegistry.getRestService();
    }
}
