/*
 * Copyright 2012 Adaptrex, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.adaptrex.core.rest.jersey;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.util.Map;

import javax.ws.rs.Consumes;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyReader;
import javax.ws.rs.ext.Provider;

import com.adaptrex.core.rest.RequestBody;
import com.adaptrex.core.utilities.StringUtilities;


@Provider
@Consumes({MediaType.WILDCARD})
public class RequestBodyReader implements MessageBodyReader<RequestBody> {

	@Override
	public boolean isReadable(Class<?> type, Type genericType, 
			Annotation[] annotation, MediaType mediaType) {
		return type.equals(RequestBody.class);
	}
 
	@SuppressWarnings("unchecked")
	@Override
	public RequestBody readFrom(
			Class<RequestBody> clazz, Type genericType, Annotation[] annotations,
			MediaType mediaType, MultivaluedMap<String, String> httpHeaders,
			InputStream entityStream) throws IOException, WebApplicationException {
		
		BufferedReader br = new BufferedReader(new InputStreamReader(entityStream));
		StringBuilder sb = new StringBuilder();
    	String line;
    	while ((line = br.readLine()) != null) {
    		sb.append(line);
    	} 
    	String post = sb.toString();
    	
		return new RequestBody((Map<String,Object>) StringUtilities.fromJson(post, Map.class));
	}
}
